CollectionOption class

Constructors

CollectionOption({bool readOnly = false, bool enableMmap = true, int maxBufferSize = 64 * 1024 * 1024})
const
CollectionOption.fromJson(Map<String, dynamic> json)
factory

Properties

enableMmap bool
final
hashCode int
The hash code for this object.
no setterinherited
maxBufferSize int
final
readOnly bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited