CollectionSchema class

Constructors

CollectionSchema({required String name, List<FieldSchema> fields = const <FieldSchema>[], Object? vectors, int? maxDocCountPerSegment})
CollectionSchema.fromJson(Map<String, dynamic> json)
factory

Properties

fields List<FieldSchema>
final
hashCode int
The hash code for this object.
no setterinherited
maxDocCountPerSegment int?
final
name String
final
primaryVector VectorSchema
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vectors List<VectorSchema>
final

Methods

get_field(String fieldName) FieldSchema?
has_field(String fieldName) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited