CollectionStats class

Constructors

CollectionStats({required int docCount, Map<String, double> indexCompleteness = const <String, double>{}})
const

Properties

docCount int
final
hashCode int
The hash code for this object.
no setterinherited
indexCompleteness Map<String, double>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited