DataType enum

Inheritance
Available extensions

Values

UNDEFINED → const DataType
BINARY → const DataType
STRING → const DataType
BOOL → const DataType
INT32 → const DataType
INT64 → const DataType
UINT32 → const DataType
UINT64 → const DataType
FLOAT → const DataType
DOUBLE → const DataType
VECTOR_BINARY32 → const DataType
VECTOR_BINARY64 → const DataType
VECTOR_FP16 → const DataType
VECTOR_FP32 → const DataType
VECTOR_FP64 → const DataType
SPARSE_VECTOR_FP16 → const DataType
SPARSE_VECTOR_FP32 → const DataType

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DataType>
A constant List of the values in this enum, in order of their declaration.