Doc class

Constructors

Doc({required String id, Map<String, dynamic>? fields, Map<String, List<double>>? vectors, double? score})

Properties

fields Map<String, dynamic>
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
score double?
final
vectors Map<String, List<double>>
final

Methods

get_all() Map<String, dynamic>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited