FieldSchema class

Implementers

Constructors

FieldSchema(String name, DataType dataType, {bool nullable = false, IndexParam? indexParam})
const

Properties

dataType DataType
final
hashCode int
The hash code for this object.
no setterinherited
indexParam IndexParam?
final
isVectorField bool
no setter
name String
final
nullable bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited