HnswIndexParam class

Inheritance

Constructors

HnswIndexParam({MetricType metricType = MetricType.IP, int m = 32, int efConstruction = 200, QuantizeType quantizeType = QuantizeType.UNDEFINED})
const

Properties

efConstruction int
final
hashCode int
The hash code for this object.
no setterinherited
m int
final
metricType MetricType
finalinherited
quantizeType QuantizeType
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type IndexType
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited