HnswQueryParam class

Inheritance

Constructors

HnswQueryParam({int ef = 32, double radius = 0.0, bool isLinear = false, bool isUsingRefiner = false})
const

Properties

ef int
final
hashCode int
The hash code for this object.
no setterinherited
isLinear bool
finalinherited
isUsingRefiner bool
finalinherited
radius double
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type IndexType
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited