IVFIndexParam class
- Inheritance
-
- Object
- IndexParam
- VectorIndexParam
- IVFIndexParam
Constructors
- IVFIndexParam({MetricType metricType = MetricType.IP, int nList = 1024, int nIters = 10, bool useSoar = false, QuantizeType quantizeType = QuantizeType.UNDEFINED})
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- metricType → MetricType
-
finalinherited
- nIters → int
-
final
- nList → int
-
final
- quantizeType → QuantizeType
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → IndexType
-
finalinherited
- useSoar → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited