IVFQueryParam class

Inheritance

Constructors

IVFQueryParam({int nprobe = 10, double scaleFactor = 10, bool isUsingRefiner = false})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isLinear bool
finalinherited
isUsingRefiner bool
finalinherited
nprobe int
final
radius double
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scaleFactor double
final
type IndexType
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited