InvertIndexParam class

Inheritance

Constructors

InvertIndexParam({bool enableRangeOptimization = true, bool enableExtendedWildcard = false})
const

Properties

enableExtendedWildcard bool
final
enableRangeOptimization bool
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type IndexType
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited