VectorQuery class

Constructors

VectorQuery(String fieldName, {required List<double> vector, String? filter, bool includeVector = false, bool includeDocId = false, List<String>? outputFields, QueryParam? queryParam})
const

Properties

fieldName String
final
filter String?
final
hashCode int
The hash code for this object.
no setterinherited
includeDocId bool
final
includeVector bool
final
outputFields List<String>?
final
queryParam QueryParam?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vector List<double>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited