ZvecCollection class

Properties

count int
no setter
dimension int
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
delete(String id) → void
deleteByFilter(String filter) → void
destroy() → void
fetch(List<String> ids) List<ZvecSearchHit>
flush() → void
hasField(String field) bool
insert({required String id, required List<double> vector, String? content, Map<String, dynamic>? metadata, String? hash}) → void
insertBatch(List<ZvecInsertRequest> documents) → void
listSources() List<ZvecSearchHit>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
optimize() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create({required String path, required int dimension, String name = 'default'}) ZvecCollection
createOrOpen({required String path, required int dimension, String name = 'default'}) ZvecCollection
open(String path) ZvecCollection