ZvecInsertRequest class

Constructors

ZvecInsertRequest({required String id, required List<double> vector, String? content, Map<String, dynamic>? metadata, String? hash})
const

Properties

content String?
final
hash String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
metadata Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vector List<double>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited