Collection class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- option → CollectionOption
-
final
- path → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schema → CollectionSchema
-
final
- stats → CollectionStats
-
no setter
Methods
-
close(
) → void -
delete(
List< String> ids) → List<Status> -
delete_by_filter(
String filter) → void -
destroy(
) → void -
fetch(
List< String> ids) → Map<String, Doc> -
flush(
) → void -
insert(
List< Doc> docs) → List<Status> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
optimize(
) → void -
query(
VectorQuery query, {int topk = 10}) → List< Doc> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited