StatusCode enum
Values
- OK → const StatusCode
- NOT_FOUND → const StatusCode
- ALREADY_EXISTS → const StatusCode
- INVALID_ARGUMENT → const StatusCode
- PERMISSION_DENIED → const StatusCode
- FAILED_PRECONDITION → const StatusCode
- RESOURCE_EXHAUSTED → const StatusCode
- UNAVAILABLE → const StatusCode
- INTERNAL_ERROR → const StatusCode
- NOT_SUPPORTED → const StatusCode
- UNKNOWN → const StatusCode
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
StatusCode> - A constant List of the values in this enum, in order of their declaration.