VectorSchema class
- Inheritance
-
- Object
- FieldSchema
- VectorSchema
Constructors
- VectorSchema(String name, DataType dataType, int dimension, {IndexParam? indexParam = const HnswIndexParam(), bool nullable = false})
-
const
Properties
- dataType → DataType
-
finalinherited
- dimension → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- indexParam → IndexParam?
-
finalinherited
- isVectorField → bool
-
no setteroverride
- name → String
-
finalinherited
- nullable → bool
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited