ZvecCollection class
Properties
Methods
-
close(
) → void -
delete(
String id) → void -
deleteByFilter(
String filter) → void -
destroy(
) → void -
fetch(
List< String> ids) → List<ZvecSearchHit> -
flush(
) → void -
hasField(
String field) → bool -
insert(
{required String id, required List< double> vector, String? content, Map<String, dynamic> ? metadata, String? hash}) → void -
insertBatch(
List< ZvecInsertRequest> documents) → void -
listSources(
) → List< ZvecSearchHit> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
optimize(
) → void -
search(
{required List< double> query, int topK = 5, double? minScore, String? filter}) → List<ZvecSearchHit> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
create(
{required String path, required int dimension, String name = 'default'}) → ZvecCollection -
createOrOpen(
{required String path, required int dimension, String name = 'default'}) → ZvecCollection -
open(
String path) → ZvecCollection